# <img src='icon.png' width='50' height='50' style='vertical-align:bottom'/> WikiHow Skill

How to do nearly everything.

## About
Ever wondered about how to boil an egg, or the best way to brush your teeths. This skill enables
OpenVoiceOS to anser a lot of "how to" questions with step by step guide. More detailed
information can be asked afterwods.

Information is comming from [wikihow.com](https://www.wikihow.com/)

![](gui2.gif)


## Examples
* "how to boil an egg"


## Credits
- JarbasAI
- [Wikihow](https://www.wikihow.com/)

## Category
**Daily**
**Information**

## Tags
#howto
